/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'fa', {
	border: 'نمایش خطوط frame',
	noUrl: 'لطفا مسیر URL iframe را درج کنید',
	scrolling: 'نمایش خطکشها',
	title: 'ویژگیهای IFrame',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
